@@ -19,7 +19,7 @@ my $has_PDL_stats_basic = $@ ? undef : 1;
 #  to hide the piddle from the caller to avoid arbitrary changes
 #  being applied to it.
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 our $Tolerance = 0.0;  #  for compatibility with Stats::Descr, but not used here
 
@@ -169,10 +169,10 @@ sub _standard_deviation {
     my $n = $piddle->nelem;
     if ($n > 1) {
         if ($has_PDL_stats_basic) {
-            $sd = $piddle->stdv_unbiased->sclr;
+            $sd = $piddle->stdv_unbiased;
         }
         else {
-            my $var = (($piddle ** 2)->sum - $n * $self->mean ** 2)->sclr;
+            my $var = (($piddle ** 2)->sum - $n * $self->mean ** 2);
             $sd = $var > 0 ? sqrt ($var / ($n - 1)) : 0;
         }
     }
@@ -224,7 +224,7 @@ sub _kurtosis {
 
     return undef if $n < 4;
 
-    return $piddle->kurt_unbiased->sclr 
+    return $piddle->kurt_unbiased
       if $has_PDL_stats_basic;
 
     #  do it ourselves
@@ -350,7 +350,7 @@ Statistics::Descriptive using PDL as the back-end
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
