@@ -18,7 +18,7 @@ use PDL::NiceSlice;
 
 ## no critic (ProhibitExplicitReturnUndef)
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use parent 'Statistics::Descriptive::PDL';
 
@@ -322,7 +322,7 @@ sub _mode {
     $data = $self->_deduplicate_piddle;
 
     my $wts = $self->_get_weights_piddle;
-    my $mode = $data($wts->maximum_ind)->sclr;
+    my $mode = $data->at($wts->maximum_ind);
     if ($mode > $data->max) {
         #  PDL returns strange numbers when distributions are flat
         $mode = undef;
@@ -363,7 +363,7 @@ Statistics::Descriptive::Weighted using PDL as the back-end
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
